@@ -13,12 +13,18 @@ for which a new license (GPL+exception) is in place.
 #include <QFileDialog>
 #include <QDir>
 #include <QProgressDialog>
+#include <QTextCodec>
 
 #include "dataviewer.h"
 #include "dataexportdialog.h"
 
+#define LF QChar(0x0A)  /* '\n' */
+#define CR QChar(0x0D)  /* '\r' */
 
-DataExportDialog::DataExportDialog(DataViewer * parent) : QDialog(0)
+
+DataExportDialog::DataExportDialog(DataViewer * parent) :
+		QDialog(0),
+		file(0)
 {
 	m_data = parent->tableData();
 	m_header = parent->tableHeader();
@@ -31,6 +37,18 @@ DataExportDialog::DataExportDialog(DataViewer * parent) : QDialog(0)
 	formats[tr("SQL inserts")] = "sql";
 	formats[tr("Python List")] = "py";
 	ui.formatBox->addItems(formats.keys());
+
+	ui.lineEndBox->addItem("UNIX (lf)");
+	ui.lineEndBox->addItem("Macintosh (cr)");
+	ui.lineEndBox->addItem("MS Windows (crlf)");
+
+	QStringList enc;
+	foreach (QString s, QTextCodec::availableCodecs())
+		enc << s;
+	enc.sort();
+	ui.encodingBox->addItems(enc);
+	ui.encodingBox->setCurrentIndex(enc.indexOf("UTF-8"));
+
 	connect(ui.fileButton, SIGNAL(toggled(bool)), this, SLOT(fileButton_toggled(bool)));
 	connect(ui.searchButton, SIGNAL(clicked()), this, SLOT(searchButton_clicked()));
 }
@@ -87,9 +105,24 @@ bool DataExportDialog::openStream()
 {
 	// file
 	exportFile = ui.fileButton->isChecked();
-	// clipboard
-	clipboard = QString();
-	out.setString(&clipboard);
+	if (exportFile)
+	{
+		file.setFileName(ui.fileEdit->text());
+		if (!file.open(QFile::WriteOnly | QFile::Truncate))
+		{
+			QMessageBox::warning(this, tr("Export Error"),
+								 tr("Cannot open file %1 for writting").arg(ui.fileEdit->text()));
+			return false;
+		}
+		out.setDevice(&file);
+		out.setCodec(QTextCodec::codecForName(ui.encodingBox->currentText().toLatin1()));
+	}
+	else
+	{
+		// clipboard
+		clipboard = QString();
+		out.setString(&clipboard);
+	}
 	return true;
 }
 
@@ -97,18 +130,7 @@ bool DataExportDialog::closeStream()
 {
 	out.flush();
 	if (exportFile)
-	{
-		QFile file(ui.fileEdit->text());
-		if (!file.open(QFile::WriteOnly | QFile::Truncate))
-		{
-			QMessageBox::warning(this, tr("Export Error"),
-								 tr("Cannot open file %1 for writting").arg(ui.fileEdit->text()));
-			return false;
-		}
-		QTextStream of(&file);
-		of << clipboard;
 		file.close();
-	}
 	else
 	{
 		QClipboard *c = QApplication::clipboard();
@@ -119,13 +141,16 @@ bool DataExportDialog::closeStream()
 
 bool DataExportDialog::exportCSV()
 {
-	for (int i = 0; i < m_header.size(); ++i)
+	if (header())
 	{
-		out << '"' << m_header.at(i) << '"';
-		if (i != (m_header.size() - 1))
-			out << ", ";
+		for (int i = 0; i < m_header.size(); ++i)
+		{
+			out << '"' << m_header.at(i) << '"';
+			if (i != (m_header.size() - 1))
+				out << ", ";
+		}
+		out << endl();
 	}
-	out << '\n';
 
 	for (int i = 0; i < m_data->rowCount(); ++i)
 	{
@@ -138,17 +163,24 @@ bool DataExportDialog::exportCSV()
 			if (j != (m_header.size() - 1))
 				out << ", ";
 		}
-		out << '\n';
+		out << endl();
 	}
 	return true;
 }
 
 bool DataExportDialog::exportHTML()
 {
-	out << "<html>\n<header>\n<title>Sqliteman export</title>\n</header>\n<body>\n<table border=\"1\">\n<tr>";
-	for (int i = 0; i < m_header.size(); ++i)
-		out << "<th>" << m_header.at(i) << "</th>";
-	out << "</tr>\n";
+	out << "<html>" << endl() << "<header>" << endl();
+	out << "<title>Sqliteman export</title>" << endl() << "</header>" << endl();
+	out << "<body>" << endl() << "<table border=\"1\">" << endl();
+
+	if (header())
+	{
+		out << "<tr>";
+		for (int i = 0; i < m_header.size(); ++i)
+			out << "<th>" << m_header.at(i) << "</th>";
+		out << "</tr>" << endl();
+	}
 
 	for (int i = 0; i < m_data->rowCount(); ++i)
 	{
@@ -158,48 +190,51 @@ bool DataExportDialog::exportHTML()
 		QSqlRecord r = m_data->record(i);
 		for (int j = 0; j < m_header.size(); ++j)
 			out << "<td>" << r.value(j).toString() << "</td>";
-		out << "</tr>\n";
+		out << "</tr>" << endl();
 	}
-	out << "</table>\n</body>\n</html>";
+	out << "</table>" << endl() << "</body>" << endl() << "</html>";
 	return true;
 }
 
 bool DataExportDialog::exportExcelXML()
 {
-	out << "<?xml version=\"1.0\"?>\n"
-		<< "<ss:Workbook xmlns:ss=\"urn:schemas-microsoft-com:office:spreadsheet\">\n"
-		<< "<ss:Styles><ss:Style ss:ID=\"1\"><ss:Font ss:Bold=\"1\"/></ss:Style></ss:Styles>\n"
-		<< "<ss:Worksheet ss:Name=\"Sqliteman Export\">\n"
-		<< "<ss:Table>\n";
+	out << "<?xml version=\"1.0\"?>" << endl()
+		<< "<ss:Workbook xmlns:ss=\"urn:schemas-microsoft-com:office:spreadsheet\">" << endl()
+		<< "<ss:Styles><ss:Style ss:ID=\"1\"><ss:Font ss:Bold=\"1\"/></ss:Style></ss:Styles>" << endl()
+		<< "<ss:Worksheet ss:Name=\"Sqliteman Export\">" << endl()
+		<< "<ss:Table>"<< endl();
 
 	for (int i = 0; i < m_header.size(); ++i)
-		out << "<ss:Column ss:Width=\"100\"/>\n";
+		out << "<ss:Column ss:Width=\"100\"/>" << endl();
 
-	out << "<ss:Row ss:StyleID=\"1\">\n";
-	for (int i = 0; i < m_header.size(); ++i)
-		out << "<ss:Cell><ss:Data ss:Type=\"String\">" << m_header.at(i) << "</ss:Data></ss:Cell>\n";
-	out << "</ss:Row>\n";
+	if (header())
+	{
+		out << "<ss:Row ss:StyleID=\"1\">" << endl();
+		for (int i = 0; i < m_header.size(); ++i)
+			out << "<ss:Cell><ss:Data ss:Type=\"String\">" << m_header.at(i) << "</ss:Data></ss:Cell>" << endl();
+		out << "</ss:Row>" << endl();
+	}
 
 	for (int i = 0; i < m_data->rowCount(); ++i)
 	{
 		if (!setProgress(i))
 			return false;
-		out << "<ss:Row>\n";
+		out << "<ss:Row>" << endl();
 		QSqlRecord r = m_data->record(i);
 		for (int j = 0; j < m_header.size(); ++j)
-			out << "<ss:Cell><ss:Data ss:Type=\"String\">" << r.value(j).toString() << "</ss:Data></ss:Cell>\n";
-		out << "</ss:Row>\n";
+			out << "<ss:Cell><ss:Data ss:Type=\"String\">" << r.value(j).toString() << "</ss:Data></ss:Cell>" << endl();
+		out << "</ss:Row>" << endl();
 	}
 
-	out << "</ss:Table>\n"
-		<< "</ss:Worksheet>\n"
-		<< "</ss:Workbook>\n";
+	out << "</ss:Table>" << endl()
+		<< "</ss:Worksheet>" << endl()
+		<< "</ss:Workbook>" << endl();
 	return true;
 }
 
 bool DataExportDialog::exportSql()
 {
-	out << "BEGIN TRANSACTION;\n";
+	out << "BEGIN TRANSACTION;" << endl();;
 	QString columns(m_header.join("\", \""));
 
 	for (int i = 0; i < m_data->rowCount(); ++i)
@@ -220,15 +255,15 @@ bool DataExportDialog::exportSql()
 			if (j != (m_header.size() - 1))
 				out << ", ";
 		}
-		out << ");\n";
+		out << ");" << endl();;
 	}
-	out << "COMMIT;\n";
+	out << "COMMIT;" << endl();;
 	return true;
 }
 
 bool DataExportDialog::exportPython()
 {
-	out << "[\n";
+	out << "[" << endl();
 
 	for (int i = 0; i < m_data->rowCount(); ++i)
 	{
@@ -242,9 +277,9 @@ bool DataExportDialog::exportPython()
 			if (j != (m_header.size() - 1))
 				out << ", ";
 		}
-		out << " },\n";
+		out << " }," << endl();
 	}
-	out << "]\n";
+	out << "]" << endl();
 	return true;
 }
 
@@ -277,3 +312,21 @@ void DataExportDialog::searchButton_clicked()
 	if (!fileName.isNull())
 		ui.fileEdit->setText(fileName);
 }
+
+bool DataExportDialog::header()
+{
+	return (ui.headerCheckBox->checkState() == Qt::Checked);
+}
+
+QString DataExportDialog::endl()
+{
+	int ix = ui.lineEndBox->currentIndex();
+	switch (ix)
+	{
+		case 1: return CR;
+		case 2: return QString(CR) + LF;
+		case 0:
+		default:
+			return LF;
+	}
+}
