@@ -142,6 +142,10 @@ QStringList DataViewer::tableHeader()
 
 void DataViewer::commit()
 {
+	// HACK: some Qt4 versions crash on commit/rollback when there
+	// is a new - currently edited - row in a transaction. This
+	// forces to close the editor/delegate.
+	ui.tableView->selectRow(ui.tableView->currentIndex().row());
 	SqlTableModel * model = qobject_cast<SqlTableModel *>(ui.tableView->model());
 	if (!model->submitAll())
 	{
@@ -159,6 +163,10 @@ void DataViewer::commit()
 
 void DataViewer::rollback()
 {
+	// HACK: some Qt4 versions crash on commit/rollback when there
+	// is a new - currently edited - row in a transaction. This
+	// forces to close the editor/delegate.
+	ui.tableView->selectRow(ui.tableView->currentIndex().row());
 	SqlTableModel * model = qobject_cast<SqlTableModel *>(ui.tableView->model());
 	model->revertAll();
 	model->setPendingTransaction(false);
