@@ -10,12 +10,12 @@ for which a new license (GPL+exception) is in place.
 #include <QMenuBar>
 #include <QMenu>
 #include <QProcess>
+#include <QTime>
 
 #include <QInputDialog>
 #include <QMessageBox>
 #include <QFileDialog>
 
-#include <QSqlTableModel>
 #include <QSqlDatabase>
 #include <QSqlError>
 
@@ -103,6 +103,9 @@ void LiteManWindow::initUI()
 
 	splitter->addWidget(tableTree);
 	splitter->addWidget(splitterSql);
+	splitter->setCollapsible(0, false);
+	splitter->setCollapsible(1, false);
+
 	setCentralWidget(splitter);
 
 	// Disable the UI, as long as there is no open database
@@ -158,6 +161,11 @@ void LiteManWindow::initActions()
 	execSqlAct->setCheckable(true);
 	connect(execSqlAct, SIGNAL(triggered()), this, SLOT(handleSqlEditor()));
 
+	objectBrowserAct = new QAction(tr("Object &Browser"), this);
+	objectBrowserAct->setShortcut(tr("Ctrl+B"));
+	objectBrowserAct->setCheckable(true);
+	connect(objectBrowserAct, SIGNAL(triggered()), this, SLOT(handleObjectBrowser()));
+
 	buildQueryAct = new QAction(tr("&Build Query..."), this);
 	buildQueryAct->setShortcut(tr("Ctrl+R"));
 	connect(buildQueryAct, SIGNAL(triggered()), this, SLOT(buildQuery()));
@@ -231,6 +239,9 @@ void LiteManWindow::initActions()
 	detachAct = new QAction(tr("&Detach Database"), this);
 	connect(detachAct, SIGNAL(triggered()), this, SLOT(detachDatabase()));
 
+	refreshTreeAct = new QAction(tr("&Refresh Object Tree"), this);
+	connect(refreshTreeAct, SIGNAL(triggered()), tableTree, SLOT(buildTree()));
+
 	consTriggAct = new QAction(tr("&Constraint Triggers..."), this);
 	connect(consTriggAct, SIGNAL(triggered()), this, SLOT(constraintTriggers()));
 }
@@ -255,6 +266,7 @@ void LiteManWindow::initMenus()
 	databaseMenu->addSeparator();
 	databaseMenu->addAction(buildQueryAct);
 	databaseMenu->addAction(execSqlAct);
+	databaseMenu->addAction(objectBrowserAct);
 	databaseMenu->addSeparator();
 	databaseMenu->addAction(exportSchemaAct);
 	databaseMenu->addAction(dumpDatabaseAct);
@@ -316,7 +328,7 @@ void LiteManWindow::readSettings()
 	QSettings settings("yarpen.cz", "sqliteman");
 
 	QPoint pos = settings.value("window/pos", QPoint(200, 200)).toPoint();
-	QSize size = settings.value("window/size", QSize(400, 400)).toSize();
+	QSize size = settings.value("window/size", QSize(800, 600)).toSize();
 	QByteArray splitterData = settings.value("window/splitter").toByteArray();
 
 	move(pos);
@@ -325,8 +337,10 @@ void LiteManWindow::readSettings()
 	splitterSql->restoreState(settings.value("sqleditor/splitter").toByteArray());
 	dataViewer->restoreSplitter(settings.value("dataviewer/splitter").toByteArray());
 
-	sqlEditor->setVisible(!settings.value("sqleditor/show", false).toBool());
-	handleSqlEditor();
+	sqlEditor->setVisible(settings.value("sqleditor/show", true).toBool());
+	tableTree->setVisible(settings.value("objectbrowser/show", true).toBool());
+	objectBrowserAct->setChecked(settings.value("objectbrowser/show", false).toBool());
+	execSqlAct->setChecked(settings.value("sqleditor/show", false).toBool());
 
 	QString fn(settings.value("sqleditor/filename", QString()).toString());
 	if (!fn.isNull() && !fn.isEmpty())
@@ -343,6 +357,7 @@ void LiteManWindow::writeSettings()
 	settings.setValue("window/pos", pos());
 	settings.setValue("window/size", size());
 	settings.setValue("window/splitter", splitter->saveState());
+	settings.setValue("objectbrowser/show", tableTree->isVisible());
 	settings.setValue("sqleditor/show", sqlEditor->isVisible());
 	settings.setValue("sqleditor/splitter", splitterSql->saveState());
 	settings.setValue("sqleditor/filename", sqlEditor->fileName());
@@ -455,6 +470,13 @@ void LiteManWindow::handleSqlEditor()
 	sqlEditor->setVisible(!sqlEditor->isVisible());
 	execSqlAct->setChecked(sqlEditor->isVisible());
 }
+#include <QtDebug>
+void LiteManWindow::handleObjectBrowser()
+{
+	qDebug() << "1";
+	tableTree->setVisible(!tableTree->isVisible());
+	objectBrowserAct->setChecked(tableTree->isVisible());
+}
 
 void LiteManWindow::execSql(QString query)
 {
@@ -463,16 +485,24 @@ void LiteManWindow::execSql(QString query)
 		QMessageBox::warning(this, tr("No SQL statement"), tr("You are trying to run an undefined SQL query. Hint: select your query in the editor"));
 		return;
 	}
+
+	sqlEditor->setStatusMessage();
+	QTime time;
+	time.start();
+
 	// Run query
+	SqlQueryModel * model = new SqlQueryModel(this);
+	model->setQuery(query, QSqlDatabase::database(SESSION_NAME));
+
+	if (!dataViewer->setTableModel(model))
+		return;
+
 	dataViewer->setEnabled(true);
 	dataViewer->showButtons(false);
 	dataViewer->showStatusText(true);
 
-	SqlQueryModel * model = new SqlQueryModel(this);
-	model->setQuery(query, QSqlDatabase::database(SESSION_NAME));
-
-	dataViewer->setTableModel(model);
-
+	sqlEditor->setStatusMessage(tr("Duration: %1 seconds").arg(time.elapsed() / 1000.0));
+	
 	// Check For Error in the SQL
 	if(model->lastError().isValid())
 		dataViewer->setStatusText(tr("Query Error: %1\n\n%2").arg(model->lastError().databaseText()).arg(query));
@@ -667,7 +697,7 @@ void LiteManWindow::treeItemActivated(QTreeWidgetItem * item, int /*column*/)
 			model->setSchema(item->text(1));
 			model->setTable(item->text(0));
 			model->select();
-			model->setEditStrategy(QSqlTableModel::OnManualSubmit);
+			model->setEditStrategy(SqlTableModel::OnManualSubmit);
 			dataViewer->setTableModel(model);
 		}
 	}
@@ -718,6 +748,7 @@ void LiteManWindow::buildContextMenu(QTreeWidgetItem * item)
 			break;
 
 		case TableTree::DatabaseItemType:
+			contextMenu->addAction(refreshTreeAct);
 			if (item->text(0) != "main")
 				contextMenu->addAction(detachAct);
 			break;
@@ -773,12 +804,15 @@ void LiteManWindow::describeTrigger()
 
 void LiteManWindow::runQuery(QString statement)
 {
+	SqlQueryModel * model = new SqlQueryModel(this);
+	model->setQuery(statement, QSqlDatabase::database(SESSION_NAME));
+	if (!dataViewer->setTableModel(model))
+		return;
+
 	dataViewer->setEnabled(true);
 	dataViewer->showStatusText(true);
 	dataViewer->showButtons(false);
-	SqlQueryModel * model = new SqlQueryModel(this);
-	model->setQuery(statement, QSqlDatabase::database(SESSION_NAME));
-	dataViewer->setTableModel(model);
+
 	if(model->lastError().isValid())
 		dataViewer->setStatusText(tr("Query Error: %1").arg(model->lastError().databaseText()));
 	else
