@@ -198,7 +198,7 @@ void SqlEditor::saveOnExit()
 {
 	if (!ui.sqlTextEdit->document()->isModified())
 		return;
-	int ret = QMessageBox::question(this, tr("Closing"),
+	int ret = QMessageBox::question(this, tr("Closing SQL Editor"),
 				tr("Document has been changed. Do you want do save its content?"),
 				QMessageBox::Yes, QMessageBox::No);
 	
