@@ -314,7 +314,7 @@
     <message>
         <location filename="../createtabledialog.cpp" line="83"/>
         <source>Sqliteman</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Sqliteman</translation>
     </message>
     <message>
         <location filename="../createtabledialog.cpp" line="85"/>
@@ -392,47 +392,47 @@
 <context>
     <name>DataExportDialog</name>
     <message>
-        <location filename="../dataexportdialog.cpp" line="28"/>
+        <location filename="../dataexportdialog.cpp" line="34"/>
         <source>Comma Separated Values (CSV)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="29"/>
+        <location filename="../dataexportdialog.cpp" line="35"/>
         <source>HTML</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="30"/>
+        <location filename="../dataexportdialog.cpp" line="36"/>
         <source>MS Excel XML (XLS)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="104"/>
+        <location filename="../dataexportdialog.cpp" line="113"/>
         <source>Export Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="105"/>
+        <location filename="../dataexportdialog.cpp" line="114"/>
         <source>Cannot open file %1 for writting</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="263"/>
+        <location filename="../dataexportdialog.cpp" line="298"/>
         <source>Comma Separated Value (*.csv)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="265"/>
+        <location filename="../dataexportdialog.cpp" line="300"/>
         <source>HTML (*.html)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="267"/>
+        <location filename="../dataexportdialog.cpp" line="302"/>
         <source>MS Excel XML (*.xml)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="274"/>
+        <location filename="../dataexportdialog.cpp" line="309"/>
         <source>Export to File</source>
         <translation type="unfinished"></translation>
     </message>
@@ -442,55 +442,90 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="33"/>
+        <location filename="../dataexportdialog.ui" line="118"/>
         <source>File:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="43"/>
+        <location filename="../dataexportdialog.ui" line="128"/>
         <source>S&amp;earch...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="55"/>
+        <location filename="../dataexportdialog.ui" line="140"/>
         <source>&amp;Format:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="83"/>
+        <location filename="../dataexportdialog.ui" line="158"/>
         <source>Export to:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="90"/>
+        <location filename="../dataexportdialog.ui" line="165"/>
         <source>F&amp;ile</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="100"/>
+        <location filename="../dataexportdialog.ui" line="175"/>
         <source>Cli&amp;pboard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="31"/>
+        <location filename="../dataexportdialog.cpp" line="37"/>
         <source>SQL inserts</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="32"/>
+        <location filename="../dataexportdialog.cpp" line="38"/>
         <source>Python List</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="269"/>
+        <location filename="../dataexportdialog.cpp" line="304"/>
         <source>SQL inserts (*.sql)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="271"/>
+        <location filename="../dataexportdialog.cpp" line="306"/>
         <source>Python list (*.py)</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="38"/>
+        <source>Export Options</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="50"/>
+        <source>If it is checked the table header will be exported with the data too.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="53"/>
+        <source>&amp;Export Headers Too</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="63"/>
+        <source>Specify the output encoding. UTF-8 is a good choice for most exports.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="70"/>
+        <source>E&amp;ncoding:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="80"/>
+        <source>&amp;Line End:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="90"/>
+        <source>You can choose the End of Line style here.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>DataViewer</name>
@@ -1318,11 +1353,6 @@ Row(s) returned: %1</source>
         <source>All you changes will be lost. Are you sure?</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <location filename="../sqleditor.cpp" line="201"/>
-        <source>Closing</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <location filename="../sqleditor.cpp" line="202"/>
         <source>Document has been changed. Do you want do save its content?</source>
@@ -1413,16 +1443,21 @@ Row(s) returned: %1</source>
         <source>Create view from the current select statement</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="../sqleditor.cpp" line="201"/>
+        <source>Closing SQL Editor</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SqlQueryModel</name>
     <message>
-        <location filename="../sqlmodels.cpp" line="132"/>
+        <location filename="../sqlmodels.cpp" line="158"/>
         <source>NULL value</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sqlmodels.cpp" line="142"/>
+        <location filename="../sqlmodels.cpp" line="168"/>
         <source>BLOB value</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1430,12 +1465,12 @@ Row(s) returned: %1</source>
 <context>
     <name>SqlTableModel</name>
     <message>
-        <location filename="../sqlmodels.cpp" line="42"/>
+        <location filename="../sqlmodels.cpp" line="43"/>
         <source>NULL value</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../sqlmodels.cpp" line="54"/>
+        <location filename="../sqlmodels.cpp" line="55"/>
         <source>BLOB value</source>
         <translation type="unfinished"></translation>
     </message>
@@ -1448,67 +1483,67 @@ Row(s) returned: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="37"/>
+        <location filename="../tableeditordialog.ui" line="25"/>
         <source>C&amp;reate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="84"/>
+        <location filename="../tableeditordialog.ui" line="72"/>
         <source>De&amp;sign</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="103"/>
+        <location filename="../tableeditordialog.ui" line="97"/>
         <source>Table &amp;Name:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="90"/>
+        <location filename="../tableeditordialog.ui" line="84"/>
         <source>&amp;Database:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="116"/>
+        <location filename="../tableeditordialog.ui" line="110"/>
         <source>Co&amp;lumns</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="150"/>
+        <location filename="../tableeditordialog.ui" line="132"/>
         <source>Name</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="155"/>
+        <location filename="../tableeditordialog.ui" line="137"/>
         <source>Type</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="160"/>
+        <location filename="../tableeditordialog.ui" line="142"/>
         <source>Not Null</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="165"/>
+        <location filename="../tableeditordialog.ui" line="147"/>
         <source>Default</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="173"/>
+        <location filename="../tableeditordialog.ui" line="155"/>
         <source>&amp;Add</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="180"/>
+        <location filename="../tableeditordialog.ui" line="162"/>
         <source>&amp;Remove</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="217"/>
+        <location filename="../tableeditordialog.ui" line="199"/>
         <source>Ad&amp;vanced (SQL)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="203"/>
+        <location filename="../tableeditordialog.ui" line="185"/>
         <source>If you need to use an advanced options&lt;br&gt;go to the &quot;&lt;b&gt;Advanced (SQL)&lt;/b&gt;&quot; tab.</source>
         <translation type="unfinished"></translation>
     </message>
