@@ -409,47 +409,47 @@
 <context>
     <name>DataExportDialog</name>
     <message>
-        <location filename="../dataexportdialog.cpp" line="28"/>
+        <location filename="../dataexportdialog.cpp" line="34"/>
         <source>Comma Separated Values (CSV)</source>
         <translation>Wartości rozdzielone przecinkiem (CSV)</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="29"/>
+        <location filename="../dataexportdialog.cpp" line="35"/>
         <source>HTML</source>
         <translation>HTML</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="30"/>
+        <location filename="../dataexportdialog.cpp" line="36"/>
         <source>MS Excel XML (XLS)</source>
         <translation>MS Excel XML (XLS)</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="104"/>
+        <location filename="../dataexportdialog.cpp" line="113"/>
         <source>Export Error</source>
         <translation>Błąd podczas eksportowania</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="105"/>
+        <location filename="../dataexportdialog.cpp" line="114"/>
         <source>Cannot open file %1 for writting</source>
         <translation>Nie można otworzyć pliku %1 do zapisu</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="263"/>
+        <location filename="../dataexportdialog.cpp" line="298"/>
         <source>Comma Separated Value (*.csv)</source>
         <translation>Wartości rozdzielone przecinkiem (*.csv)</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="265"/>
+        <location filename="../dataexportdialog.cpp" line="300"/>
         <source>HTML (*.html)</source>
         <translation>HTML (*.html)</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="267"/>
+        <location filename="../dataexportdialog.cpp" line="302"/>
         <source>MS Excel XML (*.xml)</source>
         <translation>MS Excel XML (*.xml)</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="274"/>
+        <location filename="../dataexportdialog.cpp" line="309"/>
         <source>Export to File</source>
         <translation>Eksport do pliku</translation>
     </message>
@@ -459,55 +459,90 @@
         <translation>Eksport danych</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="33"/>
+        <location filename="../dataexportdialog.ui" line="118"/>
         <source>File:</source>
         <translation>Plik:</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="43"/>
+        <location filename="../dataexportdialog.ui" line="128"/>
         <source>S&amp;earch...</source>
         <translation>&amp;Szukaj...</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="55"/>
+        <location filename="../dataexportdialog.ui" line="140"/>
         <source>&amp;Format:</source>
         <translation>&amp;Format:</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="83"/>
+        <location filename="../dataexportdialog.ui" line="158"/>
         <source>Export to:</source>
         <translation>Eksportuj do:</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="90"/>
+        <location filename="../dataexportdialog.ui" line="165"/>
         <source>F&amp;ile</source>
         <translation>&amp;Plik</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.ui" line="100"/>
+        <location filename="../dataexportdialog.ui" line="175"/>
         <source>Cli&amp;pboard</source>
         <translation>Cli&amp;pboard</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="31"/>
+        <location filename="../dataexportdialog.cpp" line="37"/>
         <source>SQL inserts</source>
         <translation>SQL</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="32"/>
+        <location filename="../dataexportdialog.cpp" line="38"/>
         <source>Python List</source>
         <translation>Python</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="269"/>
+        <location filename="../dataexportdialog.cpp" line="304"/>
         <source>SQL inserts (*.sql)</source>
         <translation>SQL (*.sql)</translation>
     </message>
     <message>
-        <location filename="../dataexportdialog.cpp" line="271"/>
+        <location filename="../dataexportdialog.cpp" line="306"/>
         <source>Python list (*.py)</source>
         <translation>Python (*.py)</translation>
     </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="38"/>
+        <source>Export Options</source>
+        <translation>Opcje Eksportu</translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="50"/>
+        <source>If it is checked the table header will be exported with the data too.</source>
+        <translation>Jeśli jest zaznaczone to razem z tabelą będzie eksportowany także nagłówek.</translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="53"/>
+        <source>&amp;Export Headers Too</source>
+        <translation>&amp;Eksportuj razem z nagłówkiem</translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="63"/>
+        <source>Specify the output encoding. UTF-8 is a good choice for most exports.</source>
+        <translation>Wybierz rodzaj kodowania. W większości przypadków UTF-8 jest najlepszym wyborem.</translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="70"/>
+        <source>E&amp;ncoding:</source>
+        <translation>Kodowa&amp;nie:</translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="80"/>
+        <source>&amp;Line End:</source>
+        <translation>Koniec &amp;linii:</translation>
+    </message>
+    <message>
+        <location filename="../dataexportdialog.ui" line="90"/>
+        <source>You can choose the End of Line style here.</source>
+        <translation>Tutaj możesz wybrać znak końca linii.</translation>
+    </message>
 </context>
 <context>
     <name>DataViewer</name>
@@ -1366,7 +1401,7 @@ zwrócono: %1 rekord(y/ów)</translation>
     <message>
         <location filename="../sqleditor.cpp" line="201"/>
         <source>Closing</source>
-        <translation>Zamykanie</translation>
+        <translation type="obsolete">Zamykanie</translation>
     </message>
     <message>
         <location filename="../sqleditor.cpp" line="202"/>
@@ -1458,16 +1493,21 @@ zwrócono: %1 rekord(y/ów)</translation>
         <source>Create view from the current select statement</source>
         <translation>Utwórz widok z bieżącego wyrażenia</translation>
     </message>
+    <message>
+        <location filename="../sqleditor.cpp" line="201"/>
+        <source>Closing SQL Editor</source>
+        <translation>Zamykanie edytora SQL</translation>
+    </message>
 </context>
 <context>
     <name>SqlQueryModel</name>
     <message>
-        <location filename="../sqlmodels.cpp" line="132"/>
+        <location filename="../sqlmodels.cpp" line="158"/>
         <source>NULL value</source>
         <translation>wartość NULL</translation>
     </message>
     <message>
-        <location filename="../sqlmodels.cpp" line="142"/>
+        <location filename="../sqlmodels.cpp" line="168"/>
         <source>BLOB value</source>
         <translation>wartość typu BLOB</translation>
     </message>
@@ -1475,12 +1515,12 @@ zwrócono: %1 rekord(y/ów)</translation>
 <context>
     <name>SqlTableModel</name>
     <message>
-        <location filename="../sqlmodels.cpp" line="42"/>
+        <location filename="../sqlmodels.cpp" line="43"/>
         <source>NULL value</source>
         <translation>wartość NULL</translation>
     </message>
     <message>
-        <location filename="../sqlmodels.cpp" line="54"/>
+        <location filename="../sqlmodels.cpp" line="55"/>
         <source>BLOB value</source>
         <translation>wartość typu BLOB</translation>
     </message>
@@ -1493,67 +1533,67 @@ zwrócono: %1 rekord(y/ów)</translation>
         <translation>Utwórz tabelę</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="37"/>
+        <location filename="../tableeditordialog.ui" line="25"/>
         <source>C&amp;reate</source>
         <translation>U&amp;twórz</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="84"/>
+        <location filename="../tableeditordialog.ui" line="72"/>
         <source>De&amp;sign</source>
         <translation>&amp;Projektuj</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="103"/>
+        <location filename="../tableeditordialog.ui" line="97"/>
         <source>Table &amp;Name:</source>
         <translation>&amp;Nazwa tabeli:</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="90"/>
+        <location filename="../tableeditordialog.ui" line="84"/>
         <source>&amp;Database:</source>
         <translation>Baza &amp;danych:</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="116"/>
+        <location filename="../tableeditordialog.ui" line="110"/>
         <source>Co&amp;lumns</source>
         <translation>&amp;Kolumny</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="150"/>
+        <location filename="../tableeditordialog.ui" line="132"/>
         <source>Name</source>
         <translation>Nazwa</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="155"/>
+        <location filename="../tableeditordialog.ui" line="137"/>
         <source>Type</source>
         <translation>Typ</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="160"/>
+        <location filename="../tableeditordialog.ui" line="142"/>
         <source>Not Null</source>
         <translation>Not Null</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="165"/>
+        <location filename="../tableeditordialog.ui" line="147"/>
         <source>Default</source>
         <translation>Domyślnie</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="173"/>
+        <location filename="../tableeditordialog.ui" line="155"/>
         <source>&amp;Add</source>
         <translation>Dod&amp;aj</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="180"/>
+        <location filename="../tableeditordialog.ui" line="162"/>
         <source>&amp;Remove</source>
         <translation>&amp;Usuń</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="217"/>
+        <location filename="../tableeditordialog.ui" line="199"/>
         <source>Ad&amp;vanced (SQL)</source>
         <translation>Zaa&amp;wansowane (SQL)</translation>
     </message>
     <message>
-        <location filename="../tableeditordialog.ui" line="203"/>
+        <location filename="../tableeditordialog.ui" line="185"/>
         <source>If you need to use an advanced options&lt;br&gt;go to the &quot;&lt;b&gt;Advanced (SQL)&lt;/b&gt;&quot; tab.</source>
         <translation>Jeśli chcesz użyć zaawansowanych opcji&lt;br&gt;kliknij zakładkę: &quot;Zaawansowane (SQL)&lt;/b&gt;.</translation>
     </message>
